#!/usr/bin/python3
# -*- coding: utf-8 -*-
################################################################################
#    Phoseg Copyright (C) 2012 Suizokukan
#    Contact: suizokukan at orange dot fr
#
#    This file is part of Phoseg.
#    Phoseg is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Phoseg is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Phoseg.  If not, see <http://www.gnu.org/licenses/>.
################################################################################
"""
        ❏Phoseg❏ : phoseg/IPA/IPA_data.py

        * class IPA_data : connection to the database and initialization of
          the informations concerning IPA.
"""

import phoseg.IPA.IPA_DATABASE as IPA_DATABASE

################################################################################
class IPA_data(object):
    """
        class IPA_data
    """

    IPA_length__character_to_value = {"\u0306"  : 0.5,
                                      ""  : 1,
                                      "ˑ" : 1.5,
                                      "ː" : 2,
                                     }

    IPA_stress__character_to_value = {""  : 0,
                                      "ˌ" : 1,
                                      "'" : 2,
                                      }

    IPA_tone__character_to_value = {""      : 0,
                                    "˥"     : 1,
                                    "˦"     : 2,
                                    "˧"     : 3,
                                    "˨"     : 4,
                                    "˩"     : 5,
                                    }

    #---------------------------------------------------------------------------
    def __init__(self):
        """
                IPA_data.__init__
        """
        self.database = IPA_DATABASE.IPA_DATABASE().init_from_a_database()
        self.IPA_vowels = self.database.list_of_IPA_characters["vowels"]
        self.IPA_consonants = self.database.list_of_IPA_characters["consonants"]

        # IPA_components : { name : character(s) }
        #
        # Why lists [] and not tuples () ? Since we use the sum(l,[]) trick
        # (see below) we can't use tuples.
        #
        #        PLEASE MODIFY THE DOCUMENTATION IF YOU MODIFY THIS object :
        #        documentation/Sphinx/manually_generated_RST_files/IPA_characters
        #
        self.IPA_components = { 'articulation'           :self.IPA_vowels+self.IPA_consonants,
                                'tone'                   :list(IPA_data.IPA_tone__character_to_value.keys()),
                                'stress'                 :list(IPA_data.IPA_stress__character_to_value.keys()),
                                'advanced'               :[chr(0x31F),],
                                'advanced_tongue_root'   :[chr(0x318),],
                                'apical'                 :[chr(0x33A),],
                                'breathy_voice'          :[chr(0x324),],
                                'creaky_voice'           :[chr(0x330),],
                                'dental'                 :[chr(0x32A),chr(0x346)],
                                'laminal'                :[chr(0x33B),],
                                'less_rounded'           :[chr(0x31C),],
                                'linguolabial_consonant' :[chr(0x33C),],
                                'lowered'                :[chr(0x31E),],
                                'mid_centralized'        :[chr(0x33D),],
                                'more_rounded'           :[chr(0x339),],
                                'raised'                 :[chr(0x31D),],
                                'retracted'              :[chr(0x320),],
                                'retracted_tongue_root'  :[chr(0x319),],
                                'syllabic'               :[chr(0x329),],
                                'voiced'                 :[chr(0x32C),],
                                'voiceless'              :[chr(0x325),chr(0x30A)],
                                'centralized_vowel'      :[chr(0x308),],
                                'nasalized'              :[chr(0x303),],
                                'no_audible_release'     :[chr(0x31A),],
                                'aspirated'              :["ʰ",],
                                'labialized'             :["ʷ",],
                                'labio_palatalized'      :['ᶣ',],
                                'lateral_release'        :["ˡ",],
                                'length'                 :list(IPA_data.IPA_length__character_to_value.keys()),
                                'nasal_release'          :["ⁿ",],
                                'palatalized'            :['ʲ',],
                                'pharyngealized'         :['ˤ',],
                                'rhotacized'             :['˞',],
                                'velarized'              :['ˠ',],
                                'voiced_aspirated'       :["ʱ",],
                                'glottalized'            :["ˀ"],
                                'extra_short'            :[chr(0x0306)],

                                'non_syllabic'           :[chr(0x32F),],
                                'affricate'              :[chr(0x361),chr(0x35C)],
                                }

        # Here are all characters allowed in an IPA string :
        # the standard IPA characters :
        #
        # NB :
        # if L is a list of lists : L = [ [1,2,3], [4,5,6] ]
        # then sum(L, []) returns a flattened list : [1,2,3,4,5,6]
        #
        self.IPA_components__all_characters = sum( (self.IPA_components[name] for name in self.IPA_components),
                                                   [])
        # ... and the other characters used by our format :
        self.IPA_external_characters = [ "(",
                                         ")",
                                         ",",
                                         " ",]

IPA_data = IPA_data()
