#!/usr/bin/python3
# -*- coding: utf-8 -*-
################################################################################
#    Phoseg Copyright (C) 2008 Xavier Faure
#    Contact: faure dot epistulam dot mihi dot scripsisti at orange dot fr
#
#    This file is part of Phoseg.
#    Phoseg is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Phoseg is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Phoseg.  If not, see <http://www.gnu.org/licenses/>.
################################################################################

"""
        ❏phoseg❏ : phoseg/errors/errors.py

        This file describes the exceptions raised by the module phoseg.

        * class PhoneticSegmentError
        * class PhoneticSegmentError_missing_parenthese_in_a_SIPA_string
        * class PhoneticSegmentError_unknown_character_in_a_SIPA_string
        * class PhoneticSegmentError_missing_syllable_in_a_SIPA_string
        * class PhoneticSegmentError_affricate_with_only_one_element
        * class PhoneticSegmentError_pending_non_syllabic_element
        * class DataBaseError_incoherent_database
        * class DataBaseError_incoherent_text_database
        * class DataBaseError_nodatabase
"""

from phoseg.system import unicode_analysis
import sys

################################################################################
class PhoneticSegmentError(Exception):
    """
        class PhoneticSegmentError
    """

    #---------------------------------------------------------------------------
    def msg(self,src):
        """
                class PhoneticSegmentError.msg
        """
        sys.stderr.write( "="*80+"\n" )
        sys.stderr.write( "Error from an PhoneticSegmentError* class :\n" )
        sys.stderr.write( src + "\n" )
        sys.stderr.write( "="*80+"\n" )

################################################################################
class PhoneticSegmentError_missing_parenthese_in_a_SIPA_string(PhoneticSegmentError):
    """
        class PhoneticSegmentError_missing_parenthese_in_a_SIPA_string
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, SIPA_string):
        """
                PhoneticSegmentError_missing_parenthese_in_a_SIPA_string.__init__
        """
        self.SIPA_string = SIPA_string

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                PhoneticSegmentError_missing_parenthese_in_a_SIPA_string.__str__
        """
        return "In this IPA string there aren't the same number of opened and closed parentheses : '{0}'".format(self.SIPA_string)

################################################################################
class PhoneticSegmentError_wrong_format_of_a_SIPA_string(PhoneticSegmentError):
    """
        class PhoneticSegmentError_wrong_format_of_a_SIPA_string
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, SIPA_string):
        """
                PhoneticSegmentError_wrong_format_of_a_SIPA_string.__init__
        """
        self.SIPA_string = SIPA_string

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                PhoneticSegmentError_wrong_format_of_a_SIPA_string.__str__
        """
        return "Problem with the format of this SIPA string : '{0}'".format(self.SIPA_string)    

################################################################################
class PhoneticSegmentError_unknown_character_in_a_SIPA_string(PhoneticSegmentError):
    """
        class PhoneticSegmentError_unknown_character_in_a_SIPA_string
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, SIPA_string, unknown_character):
        """
                PhoneticSegmentError_unknown_character_in_a_SIPA_string.__init__
        """
        self.SIPA_string = SIPA_string
        self.unknown_character = unknown_character

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                PhoneticSegmentError_unknown_character_in_a_SIPA_string.__str__
        """
        return "unknown character '{0}'{1} in '{2}'{3}".format(self.unknown_character,
                                                              unicode_analysis.return_an_analysis_of_a_string(self.unknown_character),
                                                              self.SIPA_string,
                                                              unicode_analysis.return_an_analysis_of_a_string(self.SIPA_string))

################################################################################
class PhoneticSegmentError_missing_syllable_in_a_SIPA_string(PhoneticSegmentError):
    """
        PhoneticSegmentError_missing_syllable_in_a_SIPA_string
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, SIPA_string):
        """
                PhoneticSegmentError_missing_syllable_in_a_SIPA_string.__init__
        """
        self.SIPA_string = SIPA_string

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                PhoneticSegmentError_missing_syllable_in_a_SIPA_string.__str__
        """
        return "Something went wrong with the following IPA string : {0}. The number of parentheses and of syllable(s) differ(s).".format(self.SIPA_string)

################################################################################
class PhoneticSegmentError_affricate_with_only_one_element(PhoneticSegmentError):
    """
        class PhoneticSegmentError_affricate_with_only_one_element
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, string):
        """
                PhoneticSegmentError_affricate_with_only_one_element.__init__
        """
        self.string = string

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                PhoneticSegmentError_affricate_with_only_one_element.__str__
        """
        return "Incorrect affricate representation; only one element is given in '{0}'.".format(self.string)

################################################################################
class PhoneticSegmentError_pending_non_syllabic_element(PhoneticSegmentError):
    """
        class PhoneticSegmentError_pending_non_syllabic_element
    """

    #---------------------------------------------------------------------------
    def __init__(self, string):
        """
                PhoneticSegmentError_pending_non_syllabic_element.__init__
        """
        self.string = string

        self.msg( str(self) )

    #---------------------------------------------------------------------------
    def __str__(self):
        """
                PhoneticSegmentError_pending_non_syllabic_element.__str__
        """
        return "Incorrect non syllabic representation; one non syllabic element is pending in '{0}'.".format(self.string)


################################################################################
class DataBaseError_incoherent_database(PhoneticSegmentError):
    """
        class DataBaseError_incoherent_database
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, message):
        """
                DataBaseError_incoherent_database.__init__
        """
        self.message = message

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                DataBaseError_incoherent_database.__str__
        """
        return "Something went wrong with the database whose structure is not coherent. Error message : {0}".format(self.message)

################################################################################
class DataBaseError_incoherent_text_database(PhoneticSegmentError):
    """
        class DataBaseError_incoherent_text_database
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, message):
        """
                DataBaseError_incoherent_text_database.__init__
        """
        self.message = message

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                DataBaseError_incoherent_text_database.__str__
        """
        return "Incoherent text file database.\nError message : {0}".format(self.message)

################################################################################
class DataBaseError_nodatabase(PhoneticSegmentError):
    """
        class DataBaseError_nodatabase
    """

    #-------------------------------------------------------------------------------------
    def __init__(self, filename):
        """
                DataBaseError_nodatabase.__init__
        """
        self.filename = filename

        self.msg( str(self) )

    #-------------------------------------------------------------------------------------
    def __str__(self):
        """
                DataBaseError_nodatabase.__str__
        """
        return "Missing database. File's name of the expected database : {0}".format(self.filename)
