#!/usr/bin/python3
# -*- coding: utf-8 -*-
################################################################################
#    Phoseg Copyright (C) 2008 Xavier Faure
#    Contact: suizokukan at orange dot fr
#
#    This file is part of Phoseg.
#    Phoseg is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Phoseg is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Phoseg.  If not, see <http://www.gnu.org/licenses/>.
################################################################################
"""
        ❏Phoseg❏ : phoseg/system/numversion.py

        version of the program

        The code in this file has to be compatible with Python 2.x and 3.x

        * class VersionOfTheProgram
"""

import os

################################################################################
class VersionOfTheProgram(object):
    """
        class VersionOfTheProgram

                Keeps the current number of version in a file.
    """

    NAME_OF_THE_FILE_WHERE_THE_NUMVERSION_IS_SAVED = "numversion"

    #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def __init__(self):
        """
                VersionOfTheProgram.__init__

                Ouvre le fichier dans lequel se trouve le numéro de version
                et initialise l'objet.
        """

        # version number + release number :
        self.numversion = ""

        #   We define the path where lies the file from this source code file; this
        # method allows to launch the code from another path that the usual
        # 'root path'.
        full_name_of_the_file = os.path.abspath(os.path.join(os.path.abspath( os.path.dirname( __file__)),
                                                self.NAME_OF_THE_FILE_WHERE_THE_NUMVERSION_IS_SAVED))


        # We ensure that the appropriate file exists :
        if not os.path.exists(full_name_of_the_file):
            # the file doesn't exist :
            raise Exception("The file where the number of version is kept doesn't exist; "+\
                            "name of the file : "+full_name_of_the_file)
            
        else:
            # the file exists : we read the number of the version :
            with open(full_name_of_the_file,"r") as f:

                self.numversion = f.read()
                # deleting of the final \n :
                self.numversion = self.numversion[0:-1]

    #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def __repr__(self):
        """
                VersionOfTheProgram.__repr__
        """
        return str(self.numversion)
                
    #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def __str__(self):
        """
                VersionOfTheProgram.__str__
        """
        return str(self.numversion)

	#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def only_the_release_number(self):
        """
				VersionOfTheProgram.only_the_release_number
		"""
        return str(self.numversion[-1])

	#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def only_the_version_number(self):
        """
				VersionOfTheProgram.only_the_version_number
		"""
        return str(self.numversion[:-1])
    
    #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def short_description(self):
        """
                VersionOfTheProgram.short_description

                This function returns a compact description of the number of the
                version.
        """
        
        res = str(self.numversion)
        res = res.replace(".","")
        return res
